********************* V-t curve simulations *********************
.SUBCKT BUFFER  1      2      3      4      5      6      7
*               d_in   pad    puref  PCLref pdref  GCLref /en
X0 1 2 3 4 5 6 OUT_buf            $ <<<------ Change buffer name here
.ENDS
********************************************************************************
.PROTECT
.LIB  'Process.lib'  Typ
.TRAN 25.0ps 15.0ns 
********************************************************************************
.TEMP   50                        $ Temperature of typical case
*------------------------------------------------------------------------------*
.PARAM  PUref_typ  =  3.300V      $ Pullup reference voltage, typ.
.PARAM  PUref_min  =  3.135V      $ Pullup reference voltage, min.
.PARAM  PUref_max  =  3.465V      $ Pullup reference voltage, max.
.PARAM  PCLref_typ =  PUref_typ   $ Power clamp reference voltage, typ.
.PARAM  PCLref_min =  PUref_min   $ Power clamp reference voltage, min.
.PARAM  PCLref_max =  PUref_max   $ Power clamp reference voltage, max.
*------------------------------------------------------------------------------*
.PARAM  PDref_typ  =  0.000V      $ Pulldown reference voltage, typ.
.PARAM  PDref_min  =  0.000V      $ Pulldown reference voltage, min.
.PARAM  PDref_max  =  0.000V      $ Pulldown reference voltage, max.
.PARAM  GCLref_typ =  PDref_typ   $ GND clamp reference voltage, typ.
.PARAM  GCLref_min =  PDref_min   $ GND clamp reference voltage, min.
.PARAM  GCLref_max =  PDref_max   $ GND clamp reference voltage, max.
********************************************************************************
.PARAM  PD_ref     = PDref_typ    $ Reference voltages for typical case
.PARAM  GCL_ref    = GCLref_typ
.PARAM  PU_ref     = PUref_typ
.PARAM  PCL_ref    = PCLref_typ
*------------------------------------------------------------------------------*
.PARAM  Ven        = PD_ref       $ Active-low enable
*.PARAM  Ven        = PU_ref       $ Active-high enable
********************************************************************************
.PARAM  Vfx_pd_on  = PU_ref
.PARAM  Vfx_pd_off = PU_ref
.PARAM  Vfx_pu_on  = PD_ref
.PARAM  Vfx_pu_off = PD_ref
*
.PARAM  Rfx_pd_on  = 50
.PARAM  Rfx_pd_off = 50
.PARAM  Rfx_pu_on  = 50
.PARAM  Rfx_pu_off = 50
*
.PARAM  Cfx_pd_on  = 0.0pF
.PARAM  Cfx_pd_off = 0.0pF
.PARAM  Cfx_pu_on  = 0.0pF
.PARAM  Cfx_pu_off = 0.0pF
********************************************************************************
.MEASURE TRAN  Vpower           PARAM = 'PU_ref-PD_ref'
.MEASURE TRAN  Vfixture_pd_on   PARAM = Vfx_pd_on
.MEASURE TRAN  Vfixture_pd_off  PARAM = Vfx_pd_off
.MEASURE TRAN  Vfixture_pu_on   PARAM = Vfx_pu_on
.MEASURE TRAN  Vfixture_pu_off  PARAM = Vfx_pu_off
.MEASURE TRAN  Rfixture_pd_on   PARAM = Rfx_pd_on
.MEASURE TRAN  Rfixture_pd_off  PARAM = Rfx_pd_off
.MEASURE TRAN  Rfixture_pu_on   PARAM = Rfx_pu_on
.MEASURE TRAN  Rfixture_pu_off  PARAM = Rfx_pu_off
.MEASURE TRAN  Cfixture_pd_on   PARAM = Cfx_pd_on
.MEASURE TRAN  Cfixture_pd_off  PARAM = Cfx_pd_off
.MEASURE TRAN  Cfixture_pu_on   PARAM = Cfx_pu_on
.MEASURE TRAN  Cfixture_pu_off  PARAM = Cfx_pu_off
********************************************************************************
.OPTIONS BRIEF INGOLD NUMDGT=8 CO=132 ACCT=0 NOWARN ACCURATE RMAX=0.5
*.OPTIONS POST=1 POST_VERSION=9007 PROBE
.PRINT TRAN Pulldown_on  = V(Out_pd_on)
+           Pulldown_off = V(Out_pd_off)
+           Pullup_on    = V(Out_pu_on)
+           Pullup_off   = V(Out_pu_off)
********************************************************************************
Vrefpd     pdref   0  DC = PD_ref
VrefGNDcl  GCLref  0  DC = GCL_ref
Vrefpu     puref   0  DC = PU_ref
VrefPOWcl  PCLref  0  DC = PCL_ref
*
Von        Von     0  DC = Ven
Voff       Voff    0  DC = 'PU_ref-(Ven-PD_ref)'
*
Vpls_r  Pls_r  0  PWL  0.0ns PD_ref 1.0ps PU_ref 100ns PU_ref
Vpls_f  Pls_f  0  PWL  0.0ns PU_ref 1.0ps PD_ref 100ns PD_ref
******************************************************************* pull-down on
Xdrv_pd_on   Pls_f     Out_pd_on   puref  PCLref  pdref  GCLref  Von  BUFFER
Rfxt_pd_on   V_pd_on   Out_pd_on   Rfx_pd_on
Cfxt_pd_on   V_pd_on   Out_pd_on   Cfx_pd_on
Vfxt_pd_on   V_pd_on   0           Vfx_pd_on
*----------------------------------------------------------------- pull-down off
Xdrv_pd_off  Pls_r     Out_pd_off  puref  PCLref  pdref  GCLref  Von  BUFFER
Rfxt_pd_off  V_pd_off  Out_pd_off  Rfx_pd_off
Cfxt_pd_off  V_pd_off  Out_pd_off  Cfx_pd_off
Vfxt_pd_off  V_pd_off  0           Vfx_pd_off
*-------------------------------------------------------------------- pull-up on
Xdrv_pu_on   Pls_r     Out_pu_on   puref  PCLref  pdref  GCLref  Von  BUFFER
Rfxt_pu_on   V_pu_on   Out_pu_on   Rfx_pu_on
Cfxt_pu_on   V_pu_on   Out_pu_on   Cfx_pu_on
Vfxt_pu_on   V_pu_on   0           Vfx_pu_on
*------------------------------------------------------------------- pull-up off
Xdrv_pu_off  Pls_f     Out_pu_off  puref  PCLref  pdref  GCLref  Von  BUFFER
Rfxt_pu_off  V_pu_off  Out_pu_off  Rfx_pu_off
Cfxt_pu_off  V_pu_off  Out_pu_off  Cfx_pu_off
Vfxt_pu_off  V_pu_off  0           Vfx_pu_off
********************************************************************************
.UNPROTECT
********************************************************************************
.ALTER                            $ Minimum case
.PROTECT
.DEL LIB  'Process.lib'  Typ
.LIB      'Process.lib'  Slow
.TEMP   100                       $ Temperature for minimum case
.PARAM  PD_ref     = PDref_min    $ Reference voltages for minimum case
.PARAM  GCL_ref    = GCLref_min
.PARAM  PU_ref     = PUref_min
.PARAM  PCL_ref    = PCLref_min
.UNPROTECT
********************************************************************************
.ALTER                            $ Maximum case
.PROTECT
.DEL LIB  'Process.lib'  Slow
.LIB      'Process.lib'  Fast
.TEMP   0                         $ Temperature for maximum case
.PARAM  PD_ref     = PDref_max    $ Reference voltages for maximum case
.PARAM  GCL_ref    = GCLref_max
.PARAM  PU_ref     = PUref_max
.PARAM  PCL_ref    = PCLref_max
.UNPROTECT
********************************************************************************
.END
********************* I-V curve simulations *********************
.SUBCKT BUFFER  1      2      3      4      5      6      7
*               d_in   pad    puref  PCLref pdref  GCLref /en
X0 1 2 3 4 5 6 OUT_buf            $ <<<------ Change buffer name here
.ENDS
********************************************************************************
.PROTECT
.LIB  'Process.lib'  Typ
********************************************************************************
.TEMP   50                        $ Temperature of typical case
*------------------------------------------------------------------------------*
.PARAM  Resolution =  5.0mV       $ Voltage resolution of sweep
********************************************************************************
.PARAM  PUref_typ  =  3.300V      $ Pullup reference voltage, typ.
.PARAM  PUref_min  =  3.135V      $ Pullup reference voltage, min.
.PARAM  PUref_max  =  3.465V      $ Pullup reference voltage, max.
.PARAM  PCLref_typ =  PUref_typ   $ Power clamp reference voltage, typ.
.PARAM  PCLref_min =  PUref_min   $ Power clamp reference voltage, min.
.PARAM  PCLref_max =  PUref_max   $ Power clamp reference voltage, max.
*------------------------------------------------------------------------------*
.PARAM  PDref_typ  =  0.000V      $ Pulldown reference voltage, typ.
.PARAM  PDref_min  =  0.000V      $ Pulldown reference voltage, min.
.PARAM  PDref_max  =  0.000V      $ Pulldown reference voltage, max.
.PARAM  GCLref_typ =  PDref_typ   $ GND clamp reference voltage, typ.
.PARAM  GCLref_min =  PDref_min   $ GND clamp reference voltage, min.
.PARAM  GCLref_max =  PDref_max   $ GND clamp reference voltage, max.
********************************************************************************
.PARAM  PD_ref     = PDref_typ    $ Reference voltages for typical case
.PARAM  GCL_ref    = GCLref_typ
.PARAM  PU_ref     = PUref_typ
.PARAM  PCL_ref    = PCLref_typ
*------------------------------------------------------------------------------*
.PARAM  Ven        = PD_ref       $ Active-low enable
*.PARAM  Ven        = PU_ref       $ Active-high enable
********************************************************************************
.MEASURE TRAN  Vpower        PARAM = 'PU_ref-PD_ref'
.MEASURE TRAN  Pulldown_ref  PARAM = PD_ref
.MEASURE TRAN  GND_cl_ref    PARAM = GCL_ref
.MEASURE TRAN  Pullup_ref    PARAM = PU_ref
.MEASURE TRAN  POWER_cl_ref  PARAM = PCL_ref
********************************************************************************
.TRAN  Step_t  Sweep_t  START= Sweep_d
.OPTIONS BRIEF INGOLD NUMDGT=10 CO=132 ACCT=0 NOWARN ACCURATE RMAX=0.5
*.OPTIONS POST=1 POST_VERSION=9007 PROBE
.PRINT TRAN
+ V_sweep      = PAR('Resolution*(TIME-Sweep_d)/Step_t + SWstart')
+ I_pulldown   = I(Vpulldown)
+ I_gndclamp   = PAR('0')
+ I_pullup     = I(Vpullup)
+ I_powerclamp = PAR('0')
********************************************************************************
Vrefpd     pdref   0  DC = PD_ref
VrefGNDcl  GCLref  0  DC = GCL_ref
Vrefpu     puref   0  DC = PU_ref
VrefPOWcl  PCLref  0  DC = PCL_ref
*
Von        Von     0  DC = Ven
Voff       Voff    0  DC = 'PU_ref-(Ven-PD_ref)'
*------------------------------------------------------------------------------*
.PARAM
+ DRspan        = 'PUref_typ-PDref_typ + Resolution'
+ CLspan        = 'PCLref_typ-GCLref_typ + Resolution'
*
+ PCLstart_typ  = 'PCLref_typ - max(PUref_typ +   (DRspan) , PCLref_typ +   (CLspan))'
+ PCLend_typ    = 'PCLref_typ - min(PUref_typ - 2*(DRspan) , PCLref_typ - 2*(CLspan))'
+ GCLstart_typ  = 'min(PDref_typ -   (DRspan) , GCLref_typ -   (CLspan)) - GCLref_typ'
+ GCLend_typ    = 'max(PDref_typ + 2*(DRspan) , GCLref_typ + 2*(CLspan)) - GCLref_typ'
*
+ PCLstart_min  = 'PCLref_min - max(PUref_min +   (DRspan) , PCLref_min +   (CLspan))'
+ PCLend_min    = 'PCLref_min - min(PUref_min - 2*(DRspan) , PCLref_min - 2*(CLspan))'
+ GCLstart_min  = 'min(PDref_min -   (DRspan) , GCLref_min -   (CLspan)) - GCLref_min'
+ GCLend_min    = 'max(PDref_min + 2*(DRspan) , GCLref_min + 2*(CLspan)) - GCLref_min'
*
+ PCLstart_max  = 'PCLref_max - max(PUref_max +   (DRspan) , PCLref_max +   (CLspan))'
+ PCLend_max    = 'PCLref_max - min(PUref_max - 2*(DRspan) , PCLref_max - 2*(CLspan))'
+ GCLstart_max  = 'min(PDref_max -   (DRspan) , GCLref_max -   (CLspan)) - GCLref_max'
+ GCLend_max    = 'max(PDref_max + 2*(DRspan) , GCLref_max + 2*(CLspan)) - GCLref_max'
*
+ nPCLstart     = 'min(PCLstart_typ,min(PCLstart_min,PCLstart_max))'
+ xPCLend       = 'max(PCLend_typ  ,max(PCLend_min  ,PCLend_max))'
+ nGCLstart     = 'min(GCLstart_typ,min(GCLstart_min,GCLstart_max))'
+ xGCLend       = 'max(GCLend_typ  ,max(GCLend_min  ,GCLend_max))'
*
+ SWstart       = 'min(-1*DRspan,min(nPCLstart,nGCLstart))'
+ SWend         = 'max(   DRspan,max(xPCLend  ,xGCLend))'
*
+ Step_t        = 1.0ms                $ Step size of sweep
+ Sweep_d       = 1.0us                $ Delay before sweep begins
+ Sweep_t       = 'Sweep_d + Step_t*(SWend-SWstart)/Resolution'
********************************************************************************
Vpulldown     pdref   pulldown     PWL
+  0ms                                                                             0V
+  'Sweep_d + Step_t *                      max(0,-1*DRspan-SWstart) /Resolution'  'DRspan'
+  'Sweep_d + Step_t *          (3*DRspan + max(0,-1*DRspan-SWstart))/Resolution'  '-2*DRspan'
+  'Sweep_t + Sweep_d'                                                             0V
Vpullup       puref   pullup       PWL
+  0ms                                                                             0V
+  'Sweep_d + Step_t *                      max(0,-1*SWstart-DRspan) /Resolution'  '-1*DRspan'
+  'Sweep_d + Step_t *          (3*DRspan + max(0,-1*SWstart-DRspan))/Resolution'  '2*DRspan'
+  'Sweep_t + Sweep_d'                                                             0V
********************************************************************************
Xpulldown   pdref  pulldown     puref  PCLref  pdref  GCLref  Von   BUFFER
*------------------------------------------------------------------------------*
Xpullup     puref  pullup       puref  PCLref  pdref  GCLref  Von   BUFFER
.UNPROTECT
********************************************************************************
.ALTER                            $ Minimum case
.PROTECT
.DEL LIB  'Process.lib'  Typ
.LIB      'Process.lib'  Slow
.TEMP   100                       $ Temperature for minimum case
.PARAM  PD_ref     = PDref_min    $ Reference voltages for minimum case
.PARAM  GCL_ref    = GCLref_min
.PARAM  PU_ref     = PUref_min
.PARAM  PCL_ref    = PCLref_min
.UNPROTECT
*********************************************************************************
.ALTER                            $ Maximum case
.PROTECT
.DEL LIB  'Process.lib'  Slow
.LIB      'Process.lib'  Fast
.TEMP   0                         $ Temperature for maximum case
.PARAM  PD_ref     = PDref_max    $ Reference voltages for maximum case
.PARAM  GCL_ref    = GCLref_max
.PARAM  PU_ref     = PUref_max
.PARAM  PCL_ref    = PCLref_max
.UNPROTECT
********************************************************************************
.END
